==> GeneSpring_1.0.1.tar.gz: GeneSpring/R/GSsave.exp.R <==
"GSsave.exp" <-
function(interpretation, filename="GS_R_out.txt") {

#Write the name of the experiment to the file
write.table(interpretation@expName,filename,row.names=FALSE,col.names=FALSE,quote=FALSE,sep="\t")

#We would like to be able to tell numeric parameters from non-numeric ones,
# but for now we are going to force all parameters to be non-numeric by adding the ()*R (also hiding them)
#We will now also have lost the paramter unit settings, since we removed this information.
#Have to see if we can figure out how to save this later
row.names(interpretation@expparam)<-paste(row.names(interpretation@expparam)," ()*R",sep="")

#Figure out if we have control channel data or not
if(length(interpretation@a.ctr) != 0) {
    n<-2*interpretation@numConditions

    ep <- matrix(nc=n,nr=dim(interpretation@expparam[1]))
    row.names(ep) <- row.names(interpretation@expparam)
    ep[,seq(1,n,by=2)] <- as.matrix(interpretation@expparam)
    ep[,seq(2,n,by=2)] <- "control"

    write.table(ep,filename,row.names=TRUE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)

    tab <- matrix(nc=n,nr=interpretation@ngenes)
    row.names(tab) <- row.names(interpretation@a.nor)
    tab[,seq(1,n,by=2)] <- interpretation@a.nor
    tab[,seq(2,n,by=2)] <- (interpretation@a.ctr)

    write.table(tab,filename,row.names=TRUE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)

} else {

    write.table(interpretation@expparam,filename,row.names=TRUE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)

    write.table(interpretation@a.nor,filename,row.names=TRUE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)
}

} #####End of function defintion GSsave.experiment

==> GeneSpring_2.4.0.tar.gz: GeneSpring/R/GSsave.exp.R <==
"GSsave.exp" <-
function(interpretation, filename="GS_R_out.txt") {

#Write the name of the experiment to the file
write.table(interpretation@expName,filename,row.names=FALSE,col.names=FALSE,quote=FALSE,sep="\t")

#We would like to be able to tell numeric parameters from non-numeric ones,
# but for now we are going to force all parameters to be non-numeric by adding the ()*R (also hiding them)
#We will now also have lost the paramter unit settings, since we removed this information.
#Have to see if we can figure out how to save this later
row.names(interpretation@expparam)<-paste(row.names(interpretation@expparam)," ()*R",sep="")

#Figure out if we have control channel data or not
if(length(interpretation@a.ctr) != 0) {
    n<-2*interpretation@numConditions

    ep <- matrix(nc=n,nr=dim(interpretation@expparam[1]))
    row.names(ep) <- row.names(interpretation@expparam)
    ep[,seq(1,n,by=2)] <- as.matrix(interpretation@expparam)
    ep[,seq(2,n,by=2)] <- "control"

    write.table(ep,filename,row.names=TRUE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)

    tab <- matrix(nc=n+1,nr=interpretation@ngenes)
    tab[,1] <- interpretation@genenames
    tab[,seq(2,n+1,by=2)] <- interpretation@a.nor
    tab[,seq(3,n+1,by=2)] <- (interpretation@a.ctr)

    write.table(tab,filename,row.names=FALSE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)

} else {

    write.table(interpretation@expparam,filename,row.names=TRUE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)

    tab <- matrix(nc=interpretation@numConditions+1,nr=interpretation@ngenes)
    tab[,1] <- interpretation@genenames
    tab[,2:(interpretation@numConditions+1)] <- interpretation@a.nor

    write.table(tab,filename,row.names=FALSE,col.names=FALSE,quote=FALSE,sep="\t",append=TRUE)
}

} #####End of function defintion GSsave.experiment
